@@ -318,18 +318,15 @@ integrate_to_ppi <- function(pvol, vp, nx = 100, ny = 100, xlim, ylim, zlim = c(
     })
     output <- rasters[[1]]
   }
-  eta_expected_sum <- rowSums(
-    do.call(cbind,
-            lapply(1:length(rasters), function(i) (rasters[[i]]$eta_expected))),
-    na.rm = TRUE)
+  eta_expected_sum <- 
+    rowSums(do.call(cbind, lapply(1:length(rasters), function(i) (rasters[[i]]$eta_expected))), na.rm = TRUE)
   eta_sum <-
-    rowSums(do.call(cbind, lapply(1:length(rasters), function(i)
-      (rasters[[i]]$eta))), na.rm = TRUE)
+    rowSums(do.call(cbind, lapply(1:length(rasters), function(i) (rasters[[i]]$eta))), na.rm = TRUE)
   output@data$eta_sum_expected <- eta_expected_sum
   output@data$eta_sum <- eta_sum
   output@data$R <- eta_sum / eta_expected_sum
-  output@data$VIR <- integrate_profile(vp)$vir * eta_sum / eta_expected_sum
-  output@data$VID <- integrate_profile(vp)$vid * eta_sum / eta_expected_sum
+  output@data$VIR <- integrate_profile(vp, alt_min=zlim[1], alt_max=zlim[2])$vir * eta_sum / eta_expected_sum
+  output@data$VID <- integrate_profile(vp, alt_min=zlim[1], alt_max=zlim[2])$vid * eta_sum / eta_expected_sum
 
   # calculate the overlap between vp and radiated energy
   if ("overlap" %in% param_ppi) {
@@ -511,6 +508,12 @@ add_expected_eta_to_scan <- function(scan, vp, quantity = "dens",
   attributes(eta_expected)$param <- "eta_expected"
   scan$params$eta_expected <- eta_expected
 
+  # set eta_expected values to zero whenever the reflectivity quantity is NA
+  # NA values indicate the pixel was never irradiated, so no reflectivity return expected
+  na_idx <- is.na(scan$params[[param]]) & !is.nan(scan$params[[param]])
+  scan$params[["eta_expected"]][na_idx] <- 0
+
+
   # return the scan with added scan parameters 'eta' and 'eta_expected'
   scan
 }
